@@ -1,4 +1,4 @@
-# $Id: Protocol.pm,v 1.29 1997/12/02 13:22:52 aas Exp $
+# $Id: Protocol.pm,v 1.33 1999/03/19 21:46:41 gisle Exp $
 
 package LWP::Protocol;
 
@@ -38,10 +38,12 @@ The following methods and functions are provided:
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.33 $ =~ /(\d+)\.(\d+)/);
 
 use strict;
 use Carp ();
-use HTTP::Status 'RC_INTERNAL_SERVER_ERROR';
+use HTTP::Status ();
+use HTTP::Response;
 require HTML::HeadParser;
 
 my %ImplementedBy = (); # scheme => classname
@@ -60,7 +62,6 @@ sub new
 
     my $self = bless {
 	'timeout' => 0,
-	'use_alarm' => 1,
 	'parse_head' => 1,
     }, $class;
     $self;
@@ -117,7 +118,7 @@ sub implementor
 	# try to autoload it
 	eval "require $ic";
 	if ($@) {
-	    if ($@ =~ /^Can't locate/) { #' #emacs get confused by '
+	    if ($@ =~ /Can't locate/) { #' #emacs get confused by '
 		$ic = '';
 	    } else {
 		die "$@\n";
@@ -153,11 +154,6 @@ sub request
 Get and set the timeout value in seconds
 
 
-=item $prot->use_alarm($yesno)
-
-Indicates if the library is allowed to use the core alarm()
-function to implement timeouts.
-
 =item $prot->parse_head($yesno)
 
 Should we initialize response headers from the <head> section of HTML
@@ -166,7 +162,6 @@ documents.
 =cut
 
 sub timeout    { shift->_elem('timeout',    @_); }
-sub use_alarm  { shift->_elem('use_alarm',  @_); }
 sub parse_head { shift->_elem('parse_head', @_); }
 sub max_size   { shift->_elem('max_size',   @_); }
 
@@ -198,8 +193,8 @@ sub collect
 {
     my ($self, $arg, $response, $collector) = @_;
     my $content;
-    my($use_alarm, $parse_head, $timeout, $max_size) =
-      @{$self}{qw(use_alarm parse_head timeout max_size)};
+    my($parse_head, $timeout, $max_size) =
+      @{$self}{qw(parse_head timeout max_size)};
 
     my $parser;
     if ($parse_head && $response->content_type eq 'text/html') {
@@ -213,7 +208,6 @@ sub collect
 	    if ($parser) {
 		$parser->parse($$content) or undef($parser);
 	    }
-	    alarm(0) if $use_alarm;
 	    LWP::Debug::debug("read " . length($$content) . " bytes");
 	    $response->add_content($$content);
 	    $content_size += length($$content);
@@ -223,21 +217,19 @@ sub collect
 		$response->header("X-Content-Range", "bytes 0-$content_size/$tot");
 		last;
 	    }
-	    alarm($timeout) if $use_alarm;
 	}
     }
     elsif (!ref($arg)) {
 	# filename
 	open(OUT, ">$arg") or
-	    return new HTTP::Response RC_INTERNAL_SERVER_ERROR,
-			  "Cannot write to '$arg': $!";
+	    return HTTP::Response->new(&HTTP::Status::RC_INTERNAL_SERVER_ERROR,
+			  "Cannot write to '$arg': $!");
         binmode(OUT);
         local($\) = ""; # ensure standard $OUTPUT_RECORD_SEPARATOR
 	while ($content = &$collector, length $$content) {
 	    if ($parser) {
 		$parser->parse($$content) or undef($parser);
 	    }
-	    alarm(0) if $use_alarm;
 	    LWP::Debug::debug("read " . length($$content) . " bytes");
 	    print OUT $$content;
 	    $content_size += length($$content);
@@ -247,7 +239,6 @@ sub collect
 		$response->header("X-Content-Range", "bytes 0-$content_size/$tot");
 		last;
 	    }
-	    alarm($timeout) if $use_alarm;
 	}
 	close(OUT);
     }
@@ -257,7 +248,6 @@ sub collect
 	    if ($parser) {
 		$parser->parse($$content) or undef($parser);
 	    }
-	    alarm(0) if $use_alarm;
 	    LWP::Debug::debug("read " . length($$content) . " bytes");
             eval {
 		&$arg($$content, $response, $self);
@@ -267,12 +257,11 @@ sub collect
 		$response->header('X-Died' => $@);
 		last;
 	    }
-	    alarm($timeout) if $use_alarm
 	}
     }
     else {
-	return new HTTP::Response RC_INTERNAL_SERVER_ERROR,
-				  "Unexpected collect argument  '$arg'";
+	return HTTP::Response->new(&HTTP::Status::RC_INTERNAL_SERVER_ERROR,
+				  "Unexpected collect argument  '$arg'");
     }
     $response;
 }
